@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0304';
+our $VERSION = '0.0305';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -108,7 +108,7 @@ sub generate {
 
     # Determine if we should skip certain notes given the chord flavor
     my @tones = get_scale_notes($chord_note, $scale);
-    print "\tSCALE: ",ddc(\@tones) if $self->verbose;
+    print "\tSCALE: ", ddc(\@tones) if $self->verbose;
     my @fixed;
     for my $p (@pitches) {
         my $n = Music::Note->new($p, 'midinum');
@@ -148,12 +148,7 @@ sub generate {
     # Make sure there are no duplicate pitches
     @fixed = uniq @fixed;
 
-    # DEBUGGING:
-    my @named;
-    if ($self->verbose) {
-        @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @fixed;
-        print "\tNOTES: ",ddc(\@named);
-    }
+    _verbose_notes('NOTES', @fixed) if $self->verbose;
 
     my $voice = Music::VoiceGen->new(
         pitches   => \@fixed,
@@ -173,11 +168,7 @@ sub generate {
         my $A1 = Set::Array->new(@fixed);
         my $A2 = Set::Array->new(@next_pitches);
         my @intersect = @{ $A1->intersection($A2) };
-        # DEBUGGING:
-        if ($self->verbose) {
-            my @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @intersect;
-            print "\tINTERSECT: ",ddc(\@named);
-        }
+        _verbose_notes('INTERSECT', @intersect) if $self->verbose;
         # Anticipate the next chord
         if (@intersect) {
             $chosen[-1] = _closest($chosen[-2], \@intersect);
@@ -185,14 +176,18 @@ sub generate {
     }
 
     # Show them what they've won, Bob!
-    if ($self->verbose) {
-        @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @chosen;
-        print "\tCHOSEN: ",ddc(\@named);
-    }
+    _verbose_notes('CHOSEN', @chosen) if $self->verbose;
 
     return \@chosen;
 }
 
+# Show a phrase of midinums as ISO notes
+sub _verbose_notes {
+    my ($title, @notes) = @_;
+    @notes = map { Music::Note->new($_, 'midinum')->format('ISO') } @notes;
+    print "\t$title: ", ddc(\@notes);
+}
+
 # Find the closest absolute difference to the key, in the list
 sub _closest {
     my ($key, $list) = @_;
@@ -201,7 +196,7 @@ sub _closest {
     my $min = min @diff;
     my @closest;
     for my $n (0 .. $#diff) {
-        next if $diff[$n] != $min || $list->[$n] == $key;
+        next if $diff[$n] != $min;
         push @closest, $list->[$n];
     }
     return $closest[int rand @closest];
@@ -221,7 +216,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0304
+version 0.0305
 
 =head1 SYNOPSIS
 
